/****************************************************************************
 *                                                                          *
 * QNX 4.x TERM_* function compatibility layer for  Curses                  *
 * Started by Frederick (Rick) A Niles <fniles@mitre.org>, March 2003       *
 *                                                                          *
 * Permission is hereby granted, free of charge, to any person obtaining a  *
 * copy of this software and associated documentation files (the            *
 * "Software"), to deal in the Software without restriction, including      *
 * without limitation the rights to use, copy, modify, merge, publish,      *
 * distribute, distribute with modifications, sublicense, and/or sell       *
 * copies of the Software, and to permit persons to whom the Software is    *
 * furnished to do so, subject to the following conditions:                 *
 *                                                                          *
 * The above copyright notice and this permission notice shall be included  *
 * in all copies or substantial portions of the Software.                   *
 *                                                                          *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS  *
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF               *
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.   *
 * IN NO EVENT SHALL THE ABOVE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,   *
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR    *
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR    *
 * THE USE OR OTHER DEALINGS IN THE SOFTWARE.                               *
 *                                                                          *
 * Except as contained in this notice, the name(s) of the above copyright   *
 * holders shall not be used in advertising or otherwise to promote the     *
 * sale, use or other dealings in this Software without prior written       *
 * authorization.                                                           *
 ****************************************************************************/

#ifndef _QNXTERM_H
#define _QNXTERM_H
#include <curses.h>

#ifdef __GNUC__
#define UNUSED __attribute__ ((unused))
#else
#define UNUSED /**/
#endif

/* Transition from QNX 4 TERM_* interface to POSIX Curses */
#ifdef LESS_COLOR_SLOTS
#define TERM_RED     0
#define TERM_GREEN   1
#define TERM_YELLOW  2
#define TERM_CYAN    3
/* Not really used */
#define TERM_WHITE   0

#define TERM_BLACK_BG 0
#define TERM_BLUE_BG  4
#define TERM_CYAN_BG  8
/* Not really used */
#define TERM_RED_BG   0
#else
#define TERM_RED     COLOR_RED
#define TERM_BLUE    COLOR_BLUE
#define TERM_GREEN   COLOR_GREEN
#define TERM_YELLOW  COLOR_YELLOW
#define TERM_BLACK   COLOR_BLACK
#define TERM_CYAN    COLOR_CYAN
#define TERM_WHITE   COLOR_WHITE
#define TERM_BLACK_BG COLOR_BLACK << 3
#define TERM_BLUE_BG  COLOR_BLUE << 3
#define TERM_CYAN_BG  COLOR_CYAN << 3
#define TERM_RED_BG   COLOR_RED << 3
#endif


#define TERM_BOX_FRAME     1
#define TERM_BOX_DOUBLE    2
#define TERM_BOX_NO_FRAME  0
#define TERM_NORMAL        0
#define TERM_CLS_SCR       0
#define TERM_HILIGHT       A_BOLD
#define TERM_BLINK         A_BLINK

#define TERM_VERT_R   1
#define TERM_CAP_BOTH 0
#define TERM_BAR_VERT 7
#define TERM_VERT_L   2

struct term_state_struct
{
  int num_cols;
  int num_rows;
  chtype box_arrow_up;
  chtype box_arrow_down;
  chtype box_arrow_right;
  chtype box_arrow_left;
  chtype box_horizontal;
  chtype box_vertical;
  chtype box_diamond;
  chtype box_degree;
};

extern struct term_state_struct term_state;

/**
 * Prototypes
 **/
void term_type (int y, int x, void *string, int length, int attr);
void term_color (short color_pair);
void term_printf (int y, int x, int attr, char *fmt, ...);
void term_box_fill (int y, int x, int cols, int rows, int attr, int frame, int c);
void term_flush (void);
void term_box_on (void);
void term_box_off (void);
void term_home (void);
void term_axis (int y, int x, int type, int style,
		int inside_ticks, int outside_ticks, 
		int length, int term);
void term_bar (int y, int x, int type, 
	       int active, int length, int opt);
void term_clear (int i);
void term_fill (int i);
int  term_load (void);
void term_video_on(void);
void term_key(void);
void term_restore(void);
int kbhit (void);

#endif /* _QNXTERM_H */
